@@ -164,6 +164,19 @@ static void pg_decode_truncate_v2(LogicalDecodingContext *ctx,
 					ReorderBufferChange *change);
 #endif
 
+/*
+ * Backward compatibility.
+ *
+ * This macro is only available in 9.6+.
+ */
+#if PG_VERSION_NUM < 90600
+#ifdef USE_FLOAT8_BYVAL
+#define UInt64GetDatum(X) ((Datum) (X))
+#else
+#define UInt64GetDatum(X) Int64GetDatum((int64) (X))
+#endif
+#endif
+
 void
 _PG_init(void)
 {
@@ -722,6 +735,13 @@ pg_decode_commit_txn(LogicalDecodingContext *ctx, ReorderBufferTXN *txn,
 {
 	JsonDecodingData *data = ctx->output_plugin_private;
 
+	if (txn->has_catalog_changes)
+		elog(DEBUG2, "txn has catalog changes: yes");
+	else
+		elog(DEBUG2, "txn has catalog changes: no");
+	elog(DEBUG2, "my change counter: " UINT64_FORMAT " ; # of changes: " UINT64_FORMAT " ; # of changes in memory: " UINT64_FORMAT, data->nr_changes, txn->nentries, txn->nentries_mem);
+	elog(DEBUG2, "# of subxacts: %d", txn->nsubtxns);
+
 	if (data->format_version == 2)
 		pg_decode_commit_txn_v2(ctx, txn, commit_lsn);
 	else if (data->format_version == 1)
@@ -736,13 +756,6 @@ pg_decode_commit_txn_v1(LogicalDecodingContext *ctx, ReorderBufferTXN *txn,
 {
 	JsonDecodingData *data = ctx->output_plugin_private;
 
-	if (txn->has_catalog_changes)
-		elog(DEBUG2, "txn has catalog changes: yes");
-	else
-		elog(DEBUG2, "txn has catalog changes: no");
-	elog(DEBUG2, "my change counter: " UINT64_FORMAT " ; # of changes: " UINT64_FORMAT " ; # of changes in memory: " UINT64_FORMAT, data->nr_changes, txn->nentries, txn->nentries_mem);
-	elog(DEBUG2, "# of subxacts: %d", txn->nsubtxns);
-
 	/* Transaction ends */
 	if (data->write_in_chunks)
 		OutputPluginPrepareWrite(ctx, true);
